@@ -1,27 +1,49 @@
 #' @title Create TableTree as DataFrame via gentlg
 #'
-#' @param tt TableTree object to convert to a data frame
-#' @param fontspec Font specification object
-#' @param string_map Unicode mapping for special characters
-#' @param markup_df Data frame containing markup information
-#' @return `tt` represented as a "tbl" data.frame suitable for passing
+#' @param tt (`TableTree`)\cr TableTree object to convert to a data frame
+#' @param fontspec (`font_spec`)\cr Font specification object
+#' @param string_map (`list`)\cr Unicode mapping for special characters
+#' @param markup_df (`data.frame`)\cr Data frame containing markup information
+#' @param round_type (`character(1)`)\cr the type of rounding to perform.
+#' See [formatters::format_value()] for more details.
+#' @param validate logical(1). Whether to validate the table structure using
+#'   `rtables::validate_table_struct()`. Defaults to `TRUE`. If `FALSE`, a message
+#'   will be displayed instead of stopping with an error when validation fails.
+#' @return `tt` represented as a `tbl` data.frame suitable for passing
 #'   to [tidytlg::gentlg] via the `huxme` argument.
 tt_to_tbldf <- function(
-    tt,
-    fontspec = font_spec("Times", 9L, 1),
-    string_map = default_str_map,
-    markup_df = dps_markup_df) {
-  if (!validate_table_struct(tt)) {
-    stop(
-      "invalid table structure. summarize_row_groups without ",
-      "analyze below it in layout structure?"
-    )
+  tt,
+  fontspec = font_spec("Times", 9L, 1),
+  string_map = default_str_map,
+  markup_df = dps_markup_df,
+  round_type = obj_round_type(tt),
+  validate = TRUE
+) {
+  if (validate) {
+    if (!validate_table_struct(tt)) {
+      stop(
+        "Invalid table structure detected. summarize_row_groups without ",
+        "analyze below it in layout structure?"
+      )
+    }
+  } else {
+    if (!validate_table_struct(tt)) {
+      message(
+        "Invalid table structure detected. This may cause issues in the output. ",
+        "The validation process failed, proceed with caution."
+      )
+    } else {
+      message(
+        "Table structure validation succeeded. You should not need to set validate=FALSE."
+      )
+    }
   }
   mpf <- matrix_form(
     tt,
     indent_rownames = FALSE,
     expand_newlines = FALSE,
-    fontspec = fontspec
+    fontspec = fontspec,
+    round_type = round_type
   )
 
   strmat <- mf_strings(mpf)
@@ -77,9 +99,6 @@ tt_to_tbldf <- function(
   tbldf
 }
 
-brackets_to_rtf <- function(strs) {
-  gsub("\\[\\[([^]]+)\\]\\]", "\\\\{\\1}", strs)
-}
 
 gutter_width <- .12 # inches
 
@@ -111,9 +130,10 @@ tlg_type <- function(tt) {
 }
 
 mpf_to_colspan <- function(
-    mpf,
-    string_map = default_str_map,
-    markup_df = dps_markup_df) {
+  mpf,
+  string_map = default_str_map,
+  markup_df = dps_markup_df
+) {
   if (!methods::is(mpf, "MatrixPrintForm")) {
     stop("figure out how to make this an mpf (MatrixPrintForm) first.")
   }
@@ -132,7 +152,7 @@ mpf_to_colspan <- function(
     csph <- lapply(seq_len(nspancols), function(ii) {
       spns <- mf_spans(mpf)[ii, ]
       vals <- strmat[ii, ]
-      jj <- 1 ## could start at 2 cause 1 is row label/topleft space but why complicate thigns
+      jj <- 1 ## could start at 2 cause 1 is row label/topleft space but why complicate things
       ind <- 1
       myrle <- rle(vals)
       while (jj < length(vals)) {
@@ -216,6 +236,33 @@ get_ncol <- function(tt) {
   }
 }
 
+# apply format and round_type to columns of a listing_df object and return as a dataframe
+# only for usage as input to gentlg
+listingdf_dataframe_formats <- function(df, round_type = obj_round_type(df)) {
+  if (!is(df, "listing_df")) {
+    return(df)
+  } else {
+    cols <- listing_dispcols(df)
+    df[cols] <- lapply(names(df), function(col) {
+      fmt <- obj_format(df[[col]])
+      if (!is.null(fmt)) {
+        na_str <- obj_na_str(df[[col]])
+        lbl <- obj_label(df[[col]])
+
+        df[[col]] <- sapply(df[[col]], FUN = function(x) {
+          format_value(x, format = fmt, na_str = na_str, round_type = round_type)
+        })
+
+        obj_label(df[[col]]) <- lbl
+      }
+      df[[col]]
+    })
+  }
+
+  class(df) <- "data.frame"
+  df
+}
+
 #' @name tt_to_tlgrtf
 #' @title TableTree to .rtf Conversion
 #' @description
@@ -223,39 +270,49 @@ get_ncol <- function(tt) {
 #' @details
 #' This function aids in converting the rtables TableTree into the desired .rtf file.
 #'
-#' @param tt TableTree object to convert to RTF
-#' @param file character(1). File to create, including path, but excluding
+#' @param tt (`TableTree`)\cr TableTree object to convert to RTF
+#' @param file (`character(1)`)\cr File to create, including path, but excluding
 #' .rtf extension.
-#' @param orientation Orientation of the output ("portrait" or "landscape")
-#' @param colwidths Column widths for the table
-#' @param label_width_ins Label width in inches
-#' @param fontspec Font specification object
-#' @param pg_width Page width in inches
-#' @param margins Margins in inches (top, right, bottom, left)
-#' @param paginate Whether to paginate the output
-#' @param col_gap Column gap in spaces
-#' @param verbose Whether to print verbose output
-#' @param tlgtype Type of the output (Table, Listing, or Figure)
-#' @param string_map Unicode mapping for special characters
-#' @param markup_df Data frame containing markup information
+#' @param orientation (`character`)\cr Orientation of the output ("portrait" or "landscape")
+#' @param colwidths (`numeric` vector)\cr Column widths for the table
+#' @param label_width_ins (`numeric`)\cr Label width in inches
+#' @param pagenum (`logical`)\cr Whether to add page numbers to the output.
+#' Only applicable to listings (i.e. it is ignored for tables and figures).
+#' @param fontspec (`font_spec`)\cr Font specification object
+#' @param pg_width (`numeric`)\cr Page width in inches
+#' @param margins (`numeric` vector)\cr Margins in inches (top, right, bottom, left)
+#' @param paginate (`logical`)\cr Whether to paginate the output
+#' @param col_gap (`numeric`)\cr Column gap in spaces
+#' @param verbose (`logical`)\cr Whether to print verbose output
+#' @param tlgtype (`character`)\cr Type of the output (Table, Listing, or Figure)
+#' @param string_map (`data.frame`)\cr Unicode mapping for special characters
+#' @param markup_df (`data.frame`)\cr Data frame containing markup information
 #' @param ... Additional arguments passed to gentlg
 #' @inheritParams tidytlg::gentlg
-#' @param nosplitin list(row=, col=). Path elements whose children should not be paginated within
+#' @param nosplitin (`list`)\cr list(row=, col=). Path elements whose children should not be paginated within
 #' if it can be avoided. e.g., list(col="TRT01A") means don't split within treatment arms unless
 #' all the associated columns don't fit on a single page.
-#' @param combined_rtf logical(1). In the case where the result is broken up into multiple
+#' @param combined_rtf (`logical(1)`)\cr In the case where the result is broken up into multiple
 #' parts due to width, should a combined rtf file also be created. Defaults to `FALSE`.
-#' @param one_table logical(1). If `tt` is a (non-`MatrixPrintForm`) list,
+#' @param one_table (`logical(1)`)\cr If `tt` is a (non-`MatrixPrintForm`) list,
 #' should the parts be added to the rtf within a single table (`TRUE`, the
 #' default) or as separate tables. End users will not generally need to set this.
-#' @param border_mat matrix. A `m x k` matrix where m is the number of columns of `tt`
+#' @param border_mat (`matrix`)\cr A `m x k` matrix where m is the number of columns of `tt`
 #'  and k is the number of lines the header takes up. See [tidytlg::add_bottom_borders]
 #'  for what the matrix should contain. Users should only specify this when the
 #'  default behavior does not meet their needs.
+#' @param alignments (`list`)\cr List of named lists. Vectorized.
+#' (Default = `list()`) Used to specify individual column or cell alignments.
+#' Each named list contains `row`, `col`, and `value`, which are passed to
+#' [huxtable::set_align()] to set the alignments.
+#' @param round_type (`character(1)`)\cr the type of rounding to perform.
+#' See [formatters::format_value()] for more details.
+#' @param validate logical(1). Whether to validate the table structure using
+#'  `rtables::validate_table_struct()`. Defaults to `TRUE`. If `FALSE`, a message
+#'  will be displayed when validation fails.
 #' @import rlistings
 #' @rdname tt_to_tlgrtf
 #' @export
-#' @seealso Used in all table and listing scripts
 #' @note `file` should always include path. Path will be extracted
 #' and passed separately to `gentlg`.
 #' @note When `one_table` is `FALSE`, only the width of the row label
@@ -268,36 +325,58 @@ get_ncol <- function(tt) {
 #' @return If `file` is non-NULL, this is called for the side-effect of writing
 #'   one or more RTF files. Otherwise, returns a list of `huxtable` objects.
 tt_to_tlgrtf <- function(
+  tt,
+  file = NULL,
+  orientation = c("portrait", "landscape"),
+  colwidths = def_colwidths(
     tt,
-    file = NULL,
-    orientation = c("portrait", "landscape"),
-    colwidths = def_colwidths(
-      tt,
-      fontspec,
-      col_gap = col_gap,
-      label_width_ins = label_width_ins,
-      type = tlgtype
-    ),
-    label_width_ins = 2,
-    watermark = NULL,
-    pagenum = ifelse(tlgtype == "Listing", TRUE, FALSE),
-    fontspec = font_spec("Times", 9L, 1.2),
-    pg_width = pg_width_by_orient(orientation == "landscape"),
-    margins = c(0, 0, 0, 0),
-    paginate = tlg_type(tt) == "Table",
-    col_gap = ifelse(tlgtype == "Listing", .5, 3),
-    nosplitin = list(
-      row = character(),
-      col = character()
-    ),
-    verbose = FALSE,
-    tlgtype = tlg_type(tt),
-    string_map = default_str_map,
-    markup_df = dps_markup_df,
-    combined_rtf = FALSE,
-    one_table = TRUE,
-    border_mat = make_header_bordmat(obj = tt),
-    ...) {
+    fontspec,
+    col_gap = col_gap,
+    label_width_ins = label_width_ins,
+    type = tlgtype
+  ),
+  label_width_ins = 2,
+  watermark = NULL,
+  pagenum = ifelse(tlgtype == "Listing", TRUE, FALSE),
+  fontspec = font_spec("Times", 9L, 1.2),
+  pg_width = pg_width_by_orient(orientation == "landscape"),
+  margins = c(0, 0, 0, 0),
+  paginate = tlg_type(tt) == "Table",
+  col_gap = ifelse(tlgtype == "Listing", .5, 3),
+  nosplitin = list(
+    row = character(),
+    col = character()
+  ),
+  verbose = FALSE,
+  tlgtype = tlg_type(tt),
+  string_map = default_str_map,
+  markup_df = dps_markup_df,
+  combined_rtf = FALSE,
+  one_table = TRUE,
+  border_mat = make_header_bordmat(obj = tt),
+  round_type = obj_round_type(tt),
+  alignments = list(),
+  validate = TRUE,
+  ...
+) {
+  if (validate && tlgtype == "Table" && methods::is(tt, "VTableTree")) {
+    if (!rtables::validate_table_struct(tt)) {
+      message(
+        "Invalid table structure detected. This may cause issues in the output. ",
+        "The validation process failed, proceed with caution."
+      )
+    }
+  } else if (!validate && tlgtype == "Table" && methods::is(tt, "VTableTree")) {
+    if (rtables::validate_table_struct(tt)) {
+      message(
+        "Table structure validation succeeded. You should not need to set validate=FALSE."
+      )
+    }
+  }
+
+  if (tlgtype != "Listing") {
+    pagenum <- FALSE
+  }
   orientation <- match.arg(orientation)
   newdev <- open_font_dev(fontspec)
   if (newdev) {
@@ -357,12 +436,13 @@ tt_to_tlgrtf <- function(
       )
     }
     if (methods::is(tt, "VTableTree")) {
-      hdrmpf <- matrix_form(tt[1, ])
+      hdrmpf <- matrix_form(tt[1, , keep_topleft = TRUE], round_type = round_type)
     } else if (methods::is(tt, "list") && methods::is(tt[[1]], "MatrixPrintForm")) {
       hdrmpf <- tt[[1]]
     } else {
-      hrdmpf <- tt
+      hdrmpf <- tt
     }
+
     pags <- paginate_to_mpfs(
       tt,
       fontspec = fontspec,
@@ -374,7 +454,8 @@ tt_to_tlgrtf <- function(
       margins = margins,
       lpp = NULL,
       nosplitin = nosplitin,
-      verbose = verbose
+      verbose = verbose,
+      round_type = round_type
     ) ##
     if (has_force_pag(tt)) {
       nslices <- which(
@@ -431,6 +512,8 @@ tt_to_tlgrtf <- function(
           string_map = string_map,
           markup_df = markup_df,
           border_mat = pag_bord_mats[[i]],
+          round_type = round_type,
+          alignments = alignments,
           ...
         )
       }
@@ -453,6 +536,8 @@ tt_to_tlgrtf <- function(
           colwidths = colwidths, ## this is largely ignored see note in docs
           # colwidths are already on the pags since they are mpfs
           border_mat = pag_bord_mats,
+          round_type = round_type,
+          alignments = alignments,
           ...
         )
       } else if (!is.null(file)) { # only one page after pagination
@@ -476,7 +561,8 @@ tt_to_tlgrtf <- function(
         tt_to_tbldf,
         fontspec = fontspec,
         string_map = string_map,
-        markup_df = markup_df
+        markup_df = markup_df,
+        round_type = round_type
       )
       if (one_table) {
         df <- do.call(
@@ -500,11 +586,14 @@ tt_to_tlgrtf <- function(
         tt,
         fontspec = fontspec,
         string_map = string_map,
-        markup_df = markup_df
+        markup_df = markup_df,
+        round_type = round_type
       )
     }
   } else {
     df <- tt[, listing_dispcols(tt)]
+    # apply formats and round_type and return df as a dataframe to input in gentlg
+    df <- listingdf_dataframe_formats(df, round_type = round_type)
   }
 
   ## we only care about the col labels here...
@@ -542,7 +631,8 @@ tt_to_tlgrtf <- function(
       utils::head(tt, 1),
       indent_rownames = FALSE,
       expand_newlines = FALSE,
-      fontspec = fontspec
+      fontspec = fontspec,
+      round_type = round_type
     )
     colinfo <- mpf_to_colspan(
       mpf,
@@ -627,6 +717,7 @@ tt_to_tlgrtf <- function(
     pagenum = pagenum,
     bottom_borders = border_mat,
     print.hux = !is.null(fname),
+    alignments = alignments,
     ...
   )
 }
@@ -683,8 +774,9 @@ fixup_bord_mat <- function(brdmat, hstrs) {
 }
 
 .make_header_bordmat <- function(
-    obj,
-    mpf = matrix_form(utils::head(obj, 1), expand_newlines = FALSE)) {
+  obj,
+  mpf = matrix_form(utils::head(obj, 1), expand_newlines = FALSE)
+) {
   spns <- mf_spans(mpf)
   nlh <- mf_nlheader(mpf)
   nrh <- mf_nrheader(mpf)
@@ -707,9 +799,8 @@ fixup_bord_mat <- function(brdmat, hstrs) {
 
 setGeneric(
   "make_header_bordmat",
-  function(
-      obj,
-      mpf = matrix_form(utils::head(obj, 1), expand_newlines = FALSE)) {
+  function(obj,
+           mpf = matrix_form(utils::head(obj, 1), expand_newlines = FALSE)) {
     standardGeneric("make_header_bordmat")
   }
 )
