@@ -3,19 +3,24 @@
 # Note that these tests are minimal, given that the junco functions are merely wrappers
 # of the tern functions, pointing to junco defaults.
 
+normalize_fun <- function(fun) {
+  stopifnot(is.function(fun))
+  txt <- paste(deparse(body(fun)), collapse = "")
+  gsub("\\s+", "", txt)
+}
+
 test_that("get_stats works as expected", {
   res <- junco_get_stats("kaplan_meier")
   expect_snapshot(res)
 })
 
+
 test_that("get_formats_from_stats works as expected", {
   sts <- c("quantiles_upper", "range_with_cens_info")
   res <- junco_get_formats_from_stats(sts)
 
-  environment(res[["quantiles_upper"]]) <- baseenv()
-  environment(res[["range_with_cens_info"]]) <- baseenv()
-
-  expect_snapshot(res)
+  expect_snapshot(normalize_fun(res$quantiles_upper))
+  expect_snapshot(normalize_fun(res$range_with_cens_info))
 })
 
 test_that("get_labels_from_stats works as expected", {
